"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
const constants_1 = require("../../constants");
const flow_node_1 = require("./flow_node");
/**
 * Describes a BPMN BoundaryEvent.
 *
 * These events are always attached to an activity and will only live
 * as long as that activity gets executed.
 */
class BoundaryEvent extends flow_node_1.FlowNode {
    get bpmnType() {
        return constants_1.BpmnType.boundaryEvent;
    }
    get eventType() {
        const eventIsErrorEvent = this.errorEventDefinition !== undefined;
        if (eventIsErrorEvent) {
            return constants_1.EventType.errorEvent;
        }
        const eventIsMessageEvent = this.messageEventDefinition !== undefined;
        if (eventIsMessageEvent) {
            return constants_1.EventType.messageEvent;
        }
        const eventIsSignalEvent = this.signalEventDefinition !== undefined;
        if (eventIsSignalEvent) {
            return constants_1.EventType.signalEvent;
        }
        const eventIsTimerEvent = this.timerEventDefinition !== undefined;
        if (eventIsTimerEvent) {
            return constants_1.EventType.timerEvent;
        }
        return undefined;
    }
}
exports.BoundaryEvent = BoundaryEvent;
//# sourceMappingURL=boundary_event.js.map