import { BpmnType, EventType } from '../../constants';
import { FlowNode } from './flow_node';
import { ErrorEventDefinition, MessageEventDefinition, SignalEventDefinition, TerminateEventDefinition } from './definitions/index';
/**
 * Describes a BPMN EndEvent.
 * These are used to finish a process.
 *
 * Depending on the type of EndEvent used, the process will either be finished
 * with a success message or an error.
 */
export declare class EndEvent extends FlowNode {
    readonly bpmnType: BpmnType;
    readonly eventType: EventType;
    errorEventDefinition?: ErrorEventDefinition;
    messageEventDefinition?: MessageEventDefinition;
    signalEventDefinition?: SignalEventDefinition;
    terminateEventDefinition?: TerminateEventDefinition;
    /**
     * When using a SignalEndEvent or MessageEndEvent, this property can hold a
     * definition for a payload to send with the event.
     *
     * Use this, if you do not want to use the current ProcessToken as event
     * payload.
     */
    inputValues?: any;
}
